;; Generated package description from boxy.el  -*- no-byte-compile: t -*-
(define-package "boxy" "1.1.4.0.20240326.215209" "A boxy layout framework" '((emacs "26.1")) :commit "c65a353e01610633efe20d861393a5d9605bc59d" :authors '(("Amy Grinn" . "grinn.amy@gmail.com")) :maintainer '("Amy Grinn" . "grinn.amy@gmail.com") :keywords '("tools") :url "https://gitlab.com/grinn.amy/boxy")
